@@ -21,7 +21,7 @@ import escapetheforest.world as world
 import escapetheforest.player as player
 #from escapetheforest.player import Player
 import os
-print(os.getcwd())
+#print(os.getcwd())
 
 def play():
 
@@ -78,10 +78,6 @@ if __name__ == "__main__":
     sys.path.append(os.path.dirname(os.path.realpath(__file__)))
     import escapetheforest.items as items
     import escapetheforest.world as world
-    import escapetheforest.enemies as enemies
-    import escapetheforest.tiles as tiles
-    import escapetheforest.actions as actions
     import escapetheforest.player as player
-    #from player import Player
 
     play()
