@@ -22,7 +22,7 @@ class Player(object):
     def has_stick(self):
             if items.sharpenedStick in self.inventory:
                 return True
-                print("got that stick already")
+                # print("got that stick already")
             else:
                 return False
 
@@ -35,10 +35,12 @@ class Player(object):
         else:
             print("You open your backpack and find the following items:","\n")
             for item in self.inventory:
-                print(item, "\n")
+                if item.name is not "Fists":
+                    print(item, "\n")
 
-    #def print_hp(self):
-    #    print("Your HP is:" + str(self.hp), "\n")
+        #The following code finds an instance of an object in a list of objects with list comprehension easily:
+        # if (x for x in self.inventory if x.name == "Knife"):
+        #     print("Hi")
 
 
     def print_stats(self):
