@@ -1,5 +1,7 @@
 
 import escapetheforest.items as items, escapetheforest.enemies as enemies, escapetheforest.actions as actions, escapetheforest.world as world
+import escapetheforest.player as player
+
 
 
 class mapTile(object):
@@ -30,20 +32,23 @@ class mapTile(object):
             moves.append(actions.moveSouth())
         return moves
 
-    def available_actions(self, pl):
+    def available_actions(self, player):
         # Returns all possible actions from current tile
         moves = self.adjacent_moves()
         moves.append(actions.viewInventory())
      #   moves.append(actions.viewHP())
         moves.append(actions.viewStats())
 
-        for i in range(0, len(pl.inventory)):
-            if pl.inventory[i].name == "Wooden stick":
-                moves.append(actions.sharpenStick())
-                break
+#Only append the sharpen stick action in case we got both the knife and the stick in the inventory:
+        for i in range(0, len(player.inventory)):
+            if player.inventory[i].name == "Wooden stick":
+                for j in range(0, len(player.inventory)):
+                    if player.inventory[j].name == "Knife":
+                        moves.append(actions.sharpenStick())
+                        break
 
-        for j in range(0, len(pl.inventory)):
-            if pl.inventory[j].name == "Mushroom":
+        for j in range(0, len(player.inventory)):
+            if player.inventory[j].name == "Mushroom":
                 moves.append(actions.eatMushroom())
                 break
 
@@ -75,7 +80,7 @@ It's damp and cold, so you decide to get moving. """
 
 class emptyForrestTile(mapTile):
     def tile_text(self):
-        return """Another unremarkable part of the forrest. You must forge onwards.
+        return """Another unremarkable part of the forest. Better keep moving.
         """
     def modify_player(self, player):
         # Room has no action on player
@@ -118,30 +123,33 @@ class traderTile(NPCtile):
             return """The corpse of a dead elf rots on the ground.
             """
 
-    def modify_player(self, the_player):
+    def modify_player(self, player):
         # "Room has no action on player"
         pass
 
-    def available_actions(self, pl):
+    def available_actions(self, player):
 
         moves = self.adjacent_moves()
         moves.append(actions.viewInventory())
         moves.append(actions.viewStats())
 
-        for i in range(0, len(pl.inventory)):
-            if pl.inventory[i].name == "Wooden stick":
-                moves.append(actions.sharpenStick())
-                break
+        # Only append the sharpen stick action in case we got both the knife and the stick in the inventory:
+        for i in range(0, len(player.inventory)):
+            if player.inventory[i].name == "Wooden stick":
+                for j in range(0, len(player.inventory)):
+                    if player.inventory[j].name == "Knife":
+                        moves.append(actions.sharpenStick())
+                        break
 
-        for j in range(0, len(pl.inventory)):
-            if pl.inventory[j].name == "Mushroom":
+        for j in range(0, len(player.inventory)):
+            if player.inventory[j].name == "Mushroom":
                 moves.append(actions.eatMushroom())
                 break
 
-        for j in range(0, len(pl.inventory)):
+        for j in range(0, len(player.inventory)):
             if (actions.sellMushroom() not in moves):
                 #print("The action was not found")
-                if pl.inventory[j].name == "Mushroom":
+                if player.inventory[j].name == "Mushroom":
                    # print("Mushroom exists, adding the action")
                     moves.append(actions.sellMushroom())
                     break
@@ -157,18 +165,18 @@ class enemyRoom(mapTile):
         self.metEnemy = False
         super(enemyRoom, self).__init__(x, y)
 
-    def modify_player(self, the_player):
+    def modify_player(self, player):
         if (self.enemy.is_alive()) and (self.enemy.isaggressive):
-            the_player.hp = the_player.hp - self.enemy.damage
-            if the_player.hp <= 0:
-                print("The enemy does {} damage. You have {} hp remaining.".format(self.enemy.damage, the_player.hp))
+            player.hp = player.hp - self.enemy.damage
+            if player.hp <= 0:
+                print("The enemy does {} damage. You have {} hp remaining.".format(self.enemy.damage, player.hp))
                 print("You fall to the ground, trying to crawl away from the enemy, but the enemy strikes one last blow leaving you dead on the ground...")
 
             else:
-                print("The enemy does {} damage. You have {} hp remaining.".format(self.enemy.damage, the_player.hp))
+                print("The enemy does {} damage. You have {} hp remaining.".format(self.enemy.damage, player.hp))
 
 
-    def available_actions(self, pl):
+    def available_actions(self, player):
         if self.enemy.is_alive():
             return [actions.flee(tile=self), actions.attack(enemy=self.enemy)]
         else:
@@ -176,13 +184,20 @@ class enemyRoom(mapTile):
             moves.append(actions.viewInventory())
             moves.append(actions.viewStats())
 
-            for i in range(0, len(pl.inventory)):
-                if pl.inventory[i].name == "Wooden stick":
-                    moves.append(actions.sharpenStick())
-                    break
+            # for i in range(0, len(pl.inventory)):
+            #     if pl.inventory[i].name == "Wooden stick":
+            #         moves.append(actions.sharpenStick())
+            #         break
 
-            for j in range(0, len(pl.inventory)):
-                if pl.inventory[j].name == "Mushroom":
+            # if (x for x in self.inventory if x.name == "Knife"):
+            #     print("Got knife")
+            #     if (x for x in self.inventory if x.name == "Wooden stick"):
+            #         print("got stick")
+            #         moves.append(actions.sharpenStick())
+
+
+            for j in range(0, len(player.inventory)):
+                if player.inventory[j].name == "Mushroom":
                     moves.append(actions.eatMushroom())
                     break
 
@@ -199,10 +214,11 @@ class bigSpiderTile(enemyRoom):
             self.hasAttacked = True
             return """A big spider comes to bite you!""""\n"
 
-        elif self.hasAttacked == True:
+        elif self.enemy.is_alive() and self.hasAttacked == True:
             return """The big spider attacks again!"""
         else:
-            return """A big dead spider lies on the ground here"""
+            return """A dead spider lies on the ground here"""
+
 
 class oldManTile(enemyRoom):
     def __init__(self, x, y):
@@ -217,7 +233,7 @@ class oldManTile(enemyRoom):
         elif (self.enemy.is_alive()) and (self.metEnemy == True):
             return "The old man hits you with his axe."
         else:
-            return """The corpse of an old dead man rots on the ground.
+            return """The corpse of an old dead man lies the ground.
             """
 
 class banditTile(enemyRoom):
@@ -240,7 +256,7 @@ class banditTile(enemyRoom):
             return """The bandit just stands and looks at you with an evil grin on his face"""
 
         else:
-            return """The corpse of a dead man rots on the ground.
+            return """The corpse of a dead man lies on the ground.
                         """
 
     def available_actions(self, pl):
@@ -257,7 +273,6 @@ class banditTile(enemyRoom):
             #This mf returns only the available actions from the maptile class, fuk yaaaaah!!
             return mapTile.available_actions(self, pl)
 
-
 class ringleaderTile(enemyRoom):
     def __init__(self, x, y):
         super(ringleaderTile, self).__init__(x, y, enemies.ringLeader())
@@ -267,14 +282,15 @@ class ringleaderTile(enemyRoom):
             self.hasAttacked = True
             return """'RRAAAAAHH!!'
             """
-        elif self.hasAttacked == True:
+        elif (self.enemy.is_alive()) and (self.enemy.isaggressive == True) and (self.hasAttacked == True):
             return """The bandit ringleader attacks again!"""
 
         elif (self.enemy.is_alive()) and (self.enemy.isaggressive == False):
             return ("""The bandit ringleader approaches you!
-'So, you have come to visit our dark forest? We dont want people snooping around here. Pay up 30 gold or die!'
+'So, you have come to visit our dark forest? We don't want people snooping around here. Pay up 30 gold or die!'
             """)
-
+        elif not self.enemy.is_alive():
+            return "The bandit ringleader lies dead on the ground"
         else:
             pass
 
@@ -289,8 +305,6 @@ class ringleaderTile(enemyRoom):
             #This returns only the available actions from the maptile class:
             return mapTile.available_actions(self, pl)
 
-
-
 class findKnifeTile(lootRoom):
     def __init__(self, x, y):
         super(findKnifeTile, self).__init__(x, y, items.knife())
@@ -301,12 +315,9 @@ class findKnifeTile(lootRoom):
         """
         else:
             return """
-        Another unremarkable part of the forrest. You must forge onwards.
+        Another unremarkable part of the forrest. Better keep moving.
         """
 
-
-###Create more rooms for finding gold and stumbling upon the ringleader!
-
 class leaveForrestTile(mapTile):
 
     def tile_text(self):
@@ -322,11 +333,23 @@ class findStickTile(lootRoom):
     def __init__(self, x, y):
         super(findStickTile, self).__init__(x, y, items.stick())
 
+    def add_loot(self, player):
+        for i in range(0, len(player.inventory)):
+            print(player.inventory[i])
+            if player.inventory[i].name == "Wooden stick":
+                print("Hi!")
+                pass
+            else:
+                print("Its not there")
+                player.inventory.append(self.item)
+                break
+
+
     def tile_text(self):
         if self.taken == False:
             return """You see a piece of wood, it might make a decent weapon and you pick it up. """
         else:
-            return """Another unremarkable part of the forrest. You must forge onwards."""
+            return """Another unremarkable part of the forrest. Better keep moving."""
 
 
 class findMushRoomTile(lootRoom):
@@ -337,13 +360,8 @@ class findMushRoomTile(lootRoom):
     def tile_text(self):
         if self.taken == False:
             return """Your notice something on the ground. It's a strange looking mushroom! You pick it up."""
-
-        elif self.token == 0:
-            self.token = 1
-            return """Another unremarkable part of the forrest. You must forge onwards."""
-
         else:
-            return """Another unremarkable part of the forrest. You must forge onwards."""
+            return """Another unremarkable part of the forrest. Better keep moving."""
 
 
 
